/**
 * Class Rectangle manages size, position and color attributes.
 * 
 * @author Prof. Carl B. Struck
 * @version Spring 2010
 */
public class Rectangle
{
    private int length;    // length of rectangle
    private int width;     // width of rectangle
    private int xPosition; // distance from left edge of screen
    private int yPosition; // distance from top of screen
    private String color;  // color of rectangle as a String

    /**
     * Constructor for objects of class Rectangle initializes
     * instance variables to default values.
     */
    public Rectangle()
    {
        length = 0;
        width = 0;
        xPosition = 0;
        yPosition = 0;
        color = "black";
    }

    /**
     * Assigns updated value to length field if newLength
     * parameter is greater than zero.
     */
    public void setLength(int newLength)
    {
        if (newLength > 0)
        {
            length = newLength;
        }
    }

    /**
     * Assigns updated value to width field if newWidth parameter 
     * is greater than zero.
     */
    public void setWidth(int newWidth)
    {
        if (newWidth > 0)
        {
            width = newWidth;
        }
    }

    /**
     * Adds distance parameter to horizontal field position.
     */
    public void moveHorizontal(int distance)
    {
        xPosition += distance;
    }
    
    /**
     * Adds distance parameter to vertical field position.
     */
    public void moveVertical(int distance)
    {
        yPosition += distance;
    }
    
    /**
     * Assigns updated value to rectangle color field.
     */
    public void setColor(String newColor)
    {
        color = newColor;
    }

    /**
     * Returns area of rectangle by multiplying length 
     * and width fields.
     */
    public int getArea()
    {
        return length * width;
    }

    /**
     * Displays five rectangle fields as well as the area with
     * all values preceded by descriptive labels.
     */
    public void printOut()
    {
        System.out.println("Width = " + width);
        System.out.println("Length = " + length);
        System.out.println("X position = " + xPosition);
        System.out.println("Y position = " + yPosition);
        System.out.println("Color = " + color);
        System.out.println("Area = " + getArea() );
    }
}
